@@ -236,9 +236,11 @@ grep_col_by_name_in_list <- function(l, pattern) {
 #'  be aggregated in the textEmbedLayerAggregation function.
 #' @param return_tokens If TRUE, provide the tokens used in the specified transformer model.
 #' @param device Name of device to use: 'cpu', 'gpu', or 'gpu:k' where k is a specific device number
-#' @param print_python_warnings bolean; when TRUE any warnings from python environment are printed
-#'  to the console. (Either way warnings are saved in the comment of the embedding)
 #' @param tokenizer_parallelism If TRUE this will turn on tokenizer parallelism. Default FALSE.
+#' @param model_max_length The maximum length (in number of tokens) for the inputs to the transformer model
+#' (default the value stored for the associated model).
+#' @param logging_level Set the logging level. Default: "warning".
+#' Options (ordered from less logging to more logging): critical, error, warning, info, debug
 #' @return A tibble with tokens, column specifying layer and word embeddings. Note that layer 0 is the
 #' input embedding to the transformer, and should normally not be used.
 #' @examples
@@ -259,8 +261,9 @@ textEmbedLayersOutput <- function(x,
                                   layers = 11,
                                   return_tokens = TRUE,
                                   device = "cpu",
-                                  print_python_warnings = FALSE,
-                                  tokenizer_parallelism = FALSE) {
+                                  tokenizer_parallelism = FALSE,
+                                  model_max_length = NULL,
+                                  logging_level = "error") {
 
   # Run python file with HunggingFace interface to state-of-the-art transformers
   reticulate::source_python(system.file("python",
@@ -278,19 +281,19 @@ textEmbedLayersOutput <- function(x,
     x <- data_character_variables
     sorted_layers_ALL_variables <- list()
     sorted_layers_ALL_variables$context <- list()
-    # Loop over all character variables; i_variables = 1
+    # Loop over all character variables; i_variables = 1 library(tidyverse) help(py_capture_output)
     for (i_variables in seq_len(length(data_character_variables))) {
 
       # Python file function to HuggingFace
-      textrpp_py_warnings_text_context <- reticulate::py_capture_output(
-        hg_embeddings <- hgTransformerGetEmbedding(
-          text_strings = x[[i_variables]],
-          model = model,
-          layers = layers,
-          return_tokens = return_tokens,
-          device = device,
-          tokenizer_parallelism = tokenizer_parallelism
-        )
+      hg_embeddings <- hgTransformerGetEmbedding(
+        text_strings = x[[i_variables]],
+        model = model,
+        layers = layers,
+        return_tokens = return_tokens,
+        device = device,
+        tokenizer_parallelism = tokenizer_parallelism,
+        model_max_length = model_max_length,
+        logging_level = logging_level
       )
 
       variable_x <- sortingLayers(x = hg_embeddings, layers = layers, return_tokens = return_tokens)
@@ -301,14 +304,10 @@ textEmbedLayersOutput <- function(x,
       # Adding informative comment help(comment)
       layers_string <- paste(as.character(layers), sep = " ", collapse = " ")
 
-      if (!exists("textrpp_py_warnings_text_context")) {
-        textrpp_py_warnings_text_context <- "There were no python warnings."
-      }
-
       comment(sorted_layers_ALL_variables$context) <- paste("Information about the embeddings. textEmbedLayersOutput: ",
         "model:", model, "; ",
         "layers:", layers_string, ".",
-        "Warnings from python: ", textrpp_py_warnings_text_context,
+        # "Warnings from python: ", textrpp_py_warnings_text_context,
         collapse = "\n"
       )
     }
@@ -323,15 +322,16 @@ textEmbedLayersOutput <- function(x,
     list_words <- sapply(singlewords$words, list)
     names(list_words) <- NULL
 
-    textrpp_py_warnings_text_decontext <- reticulate::py_capture_output(
-      hg_decontexts_embeddings <- hgTransformerGetEmbedding(
-        text_strings = list_words,
-        model = model,
-        layers = layers,
-        return_tokens = return_tokens,
-        device = device,
-        tokenizer_parallelism = tokenizer_parallelism
-      )
+
+    hg_decontexts_embeddings <- hgTransformerGetEmbedding(
+      text_strings = list_words,
+      model = model,
+      layers = layers,
+      return_tokens = return_tokens,
+      device = device,
+      tokenizer_parallelism = tokenizer_parallelism,
+      model_max_length = model_max_length,
+      logging_level = logging_level
     )
 
     # Sort out layers as above
@@ -362,16 +362,6 @@ textEmbedLayersOutput <- function(x,
     sorted_layers_All_decontexts
   }
 
-  if (print_python_warnings == TRUE) {
-    if (contexts == TRUE) {
-      cat(textrpp_py_warnings_text_context)
-    }
-
-    if (decontexts == TRUE) {
-      cat(textrpp_py_warnings_text_decontext)
-    }
-  }
-
   # Combine previous list and word list
   if (contexts == TRUE & decontexts == TRUE) {
     word_embeddings_with_layers <- c(sorted_layers_ALL_variables, sorted_layers_All_decontexts)
@@ -480,8 +470,9 @@ textEmbedLayerAggregation <- function(word_embeddings_layers,
 
     # Aggregate (Remove all tokens and layers; but create a cell with the information abt layers, aggregation)
     selected_layers_tokens_aggregated <- lapply(selected_layers_aggregated,
-                                                textEmbeddingAggregation,
-                                                aggregation = aggregate_tokens)
+      textEmbeddingAggregation,
+      aggregation = aggregate_tokens
+    )
 
     # Sort output
     selected_layers_aggregated_tibble[[variable_list_i]] <- dplyr::bind_rows(selected_layers_tokens_aggregated)
@@ -550,7 +541,10 @@ textEmbedLayerAggregation <- function(word_embeddings_layers,
 #' @param decontext_tokens_deselect option to deselect embeddings linked to specific tokens
 #' such as [CLS] and [SEP] for the decontext embeddings.
 #' @param device Name of device to use: 'cpu', 'gpu', or 'gpu:k' where k is a specific device number
-#' @param print_python_warnings bolean; when true any warnings from python environment are printed to the console.
+#' @param model_max_length The maximum length (in number of tokens) for the inputs to the transformer model
+#' (default the value stored for the associated model).
+#' @param logging_level Set the logging level. Default: "warning".
+#' Options (ordered from less logging to more logging): critical, error, warning, info, debug
 #' @return A tibble with tokens, a column for layer identifier and word embeddings.
 #' Note that layer 0 is the input embedding to the transformer
 #' @examples
@@ -583,7 +577,8 @@ textEmbed <- function(x,
                       decontext_tokens_select = NULL,
                       decontext_tokens_deselect = NULL,
                       device = "cpu",
-                      print_python_warnings = FALSE) {
+                      model_max_length = NULL,
+                      logging_level = "error") {
   T1_textEmbed <- Sys.time()
 
   reticulate::source_python(system.file("python", "huggingface_Interface3.py", package = "text", mustWork = TRUE))
@@ -596,7 +591,8 @@ textEmbed <- function(x,
     layers = layers,
     return_tokens = FALSE,
     device = device,
-    print_python_warnings = print_python_warnings
+    model_max_length = model_max_length,
+    logging_level = logging_level
   )
 
   # Aggregate context layers
@@ -618,10 +614,11 @@ textEmbed <- function(x,
     tokens_deselect = decontext_tokens_deselect
   )
 
-
   # Combine the words for each decontextualized embedding
-  decontextualised_embeddings_words <- dplyr::bind_cols(all_wanted_layers$decontext$single_words,
-                                                        decontextualised_embeddings)
+  decontextualised_embeddings_words <- dplyr::bind_cols(
+    all_wanted_layers$decontext$single_words,
+    decontextualised_embeddings
+  )
 
   if (decontexts == TRUE) {
     comment(decontextualised_embeddings_words) <- comment(decontextualised_embeddings[[1]])
