@@ -1,15 +1,19 @@
 
+
 #' Test whether there is a significant difference in meaning between two sets of texts
 #' (i.e., between their word embeddings).
 #' @param x Set of word embeddings from textEmbed.
 #' @param y Set of word embeddings from textEmbed.
-#' @param Npermutations Number of permutations (default 1000).
+#' @param similarity_method Character string describing type of measure to be computed;
+#' default is "cosine" (see also measures from textDistance (here computed as 1 - textDistance()) including
+#' "euclidean", "maximum", "manhattan", "canberra", "binary" and "minkowski").
+#' @param Npermutations Number of permutations (default 10000).
 #' @param method Compute a "paired" or an "unpaired" test.
 #' @param alternative Use a two or one-sided test (select one of: "two_sided", "less", "greater").
 #' @param output.permutations If TRUE, returns permuted values in output.
 #' @param N_cluster_nodes Number of cluster nodes to use (more makes computation faster; see parallel package).
 #' @param seed Set different seed.
-#' @return A list with a p-value, cosine_estimate and permuted values if output.permutations=TRUE.
+#' @return A list with a p-value, similarity score estimate and permuted values if output.permutations=TRUE.
 #' @examples
 #' x <- word_embeddings_4$harmonywords
 #' y <- word_embeddings_4$satisfactionwords
@@ -25,6 +29,7 @@
 #' @export
 textSimilarityTest <- function(x,
                                y,
+                               similarity_method = "cosine",
                                Npermutations = 10000,
                                method = "paired",
                                alternative = c("two_sided", "less", "greater"),
@@ -38,35 +43,33 @@ textSimilarityTest <- function(x,
     stop("x and y must have the same number of rows for a paired textSimilarityTest test.")
   }
   alternative <- match.arg(alternative)
-  results <- c("cosine_estimate" = NA, "p.value" = NA)
+  results_title <- paste(similarity_method, "_estimate", sep = "")
+  results <- tibble::tibble("title1" = NA, "title2" = NA)
+  colnames(results) <- c(results_title, "p.value")
 
   # Select variables beginning with V
   x1 <- dplyr::select(x, dplyr::starts_with("Dim"))
   y1 <- dplyr::select(y, dplyr::starts_with("Dim"))
 
   if (method == "paired") {
-    # Compute cosine between all pairs
-    cosine_observed <- cosines(x1, y1)
-    # Compute the data's mean of the cosine
-    results["cosine_estimate"] <- mean(abs(cosine_observed))
+    # Compute similarity between all pairs
+    ss_observed <- textSimilarity(x1, y1, method = similarity_method)
+    # Compute the data's mean of the similarity scores
+    results[1] <- mean(abs(ss_observed))
   }
 
   if (method == "unpaired") {
-    X_all <- textEmbeddingAggregation(x1, aggregation = "mean")
-    Y_all <- textEmbeddingAggregation(y1, aggregation = "mean")
-    # Compute cosine between the summed word embedding
+    X_all <- tibble::as_tibble_row(textEmbeddingAggregation(x1, aggregation = "mean"))
+    Y_all <- tibble::as_tibble_row(textEmbeddingAggregation(y1, aggregation = "mean"))
 
-    # This is to make it work with the cosines function that require several word embeddings
-    X_all <- rbind(X_all, X_all)
-    Y_all <- rbind(Y_all, Y_all)
+    # Compute similarity between the summed word embedding
+    ss_observed <- textSimilarity(X_all, Y_all, method = similarity_method)
 
-    cosine_observed <- cosines(X_all, Y_all)
-
-    # Compute the data's mean of the cosine
-    results["cosine_estimate"] <- mean(abs(cosine_observed))
+    # Compute the data's mean of the similarity scores
+    results[1] <- mean(abs(ss_observed))
   }
 
-  ### Compute comparison distribution of cosine based on randomly drawn word embeddings from both groups
+  ### Compute comparison distribution of similarity scores based on randomly drawn word embeddings from both groups
   # adding groups together.
   x1y1 <- rbind(x1, y1)
 
@@ -74,40 +77,41 @@ textSimilarityTest <- function(x,
   splitix <- parallel::splitIndices(nx = Npermutations, ncl = N_cluster_nodes)
   splitix <- splitix[sapply(splitix, length) > 0]
 
-  distribution_mean_cosine_permutated <- parallel::mclapply(splitix, function(x, xx, yy) {
-    mean_cosine_permutated <- sapply(x, function(x, xx, yy) {
+  distribution_mean_ss_permutated <- parallel::mclapply(splitix, function(x, xx, yy) {
+    mean_ss_permutated <- sapply(x, function(x, xx, yy) {
       # Get indixes for how to randomly split the word embeddings.
-      indices <- sample(c((rep(TRUE, nrow(x1y1) / 2)), (rep(FALSE, nrow(x1y1) / 2))), nrow(x1y1), replace = FALSE)
+      indices <- sample(c((rep(TRUE, ceiling(nrow(x1y1) / 2))),
+                          (rep(FALSE, floor(nrow(x1y1) / 2)))),
+                        nrow(x1y1), replace = FALSE)
       # Randomly select word embeddings into two different data frames.
       rdata1 <- x1y1[indices, ]
       rdata2 <- x1y1[!indices, ]
-      # Compute the cosine between randomly drawn word embeddings and compute the mean.
+      # Compute the semantic similarity between randomly drawn word embeddings and compute the mean.
       if (method == "paired") {
-        rcosines <- cosines(rdata1, rdata2)
-        return(mean(abs(rcosines)))
+        rand_ss <- textSimilarity(rdata1, rdata2, method = similarity_method)
+        return(mean(abs(rand_ss)))
       }
       if (method == "unpaired") {
-        R1_all <- textEmbeddingAggregation(rdata1, aggregation = "mean")
-        R2_all <- textEmbeddingAggregation(rdata2, aggregation = "mean")
-        # Compute cosine between the summed word embedding
+        R1_all <- tibble::as_tibble_row(textEmbeddingAggregation(rdata1, aggregation = "mean"))
+        R2_all <- tibble::as_tibble_row(textEmbeddingAggregation(rdata2, aggregation = "mean"))
 
-        # This is to make it work with the cosines function that require several word embeddings
-        R1_all <- rbind(R1_all, R1_all)
-        R2_all <- rbind(R2_all, R2_all)
-        rcosines <- cosines(R1_all, R2_all)
+        # Compute similarity between the summed word embedding
+        rand_ss <- textSimilarity(R1_all, R2_all, method = similarity_method)
 
-        # Compute the data's mean of the cosine
-        return(abs(rcosines))
+        # Compute the data's mean of the similarity scores
+        return(abs(rand_ss))
       }
     }, xx = xx, yy = yy)
-    return(mean_cosine_permutated)
+    return(mean_ss_permutated)
   }, xx = x, yy = y)
-  NULLresults <- unlist(distribution_mean_cosine_permutated)
+  NULLresults <- unlist(distribution_mean_ss_permutated)
 
-  # Examine how the ordered data's mean of the cosine compare with the random data's, null comparison distribution
+  # Examine how the ordered data's mean of the similarity scores compare with the random data's,
+  # null comparison distribution
   p_value <- p_value_comparing_with_Null(NULLresults,
-                                         Observedresult = results["cosine_estimate"],
-                                         alternative = alternative)
+    Observedresult = results[[1]],
+    alternative = alternative
+  )
   results["p.value"] <- p_value
   results <- as.list(results)
 
@@ -126,8 +130,10 @@ textSimilarityTest <- function(x,
   # Time
   T2_textSimilarityTest <- Sys.time()
   Time_textSimilarityTest <- T2_textSimilarityTest - T1_textSimilarityTest
-  Time_textSimilarityTest <- sprintf("Duration to run the test: %f %s", Time_textSimilarityTest,
-                                     units(Time_textSimilarityTest))
+  Time_textSimilarityTest <- sprintf(
+    "Duration to run the test: %f %s", Time_textSimilarityTest,
+    units(Time_textSimilarityTest)
+  )
   Date_textSimilarityTest <- Sys.time()
   time_date <- paste(Time_textSimilarityTest,
     "; Date created: ", Date_textSimilarityTest,
@@ -136,6 +142,7 @@ textSimilarityTest <- function(x,
   )
 
   test_description <- paste("permutations = ", Npermutations,
+    "similarity_method = ", similarity_method,
     "method = ", method,
     "alternative = ", alternative,
     collapse = " "
