@@ -7,11 +7,17 @@
 #' @importFrom tibble as_tibble
 #' @noRd
 unique_freq_words <- function(words) {
-  words_group1 <- data.frame(unlist(strsplit(tolower(words), " ")))
-  # Remove empty cells (otherwise all words are put within " ",
-  # which create problems in getUniqueWordsAndFreq or textCentrality)
-  words_group <- words_group1[words_group1 != ""]
-  words_group <- as.character(words_group)
+  # Make all words lower case
+  words <- tolower(words)
+
+  # separate words/tokens ombined with /
+  words <- gsub("/", " ", words)
+
+  # Tokenize with nltk
+  nltk <- reticulate::import("nltk")
+  tokenizerNLTK <- nltk$tokenize$word_tokenize
+  words_group <- unlist(lapply(words, tokenizerNLTK))
+
   words_groupb <- tibble::as_tibble(words_group)
   sort(words_groupb$value)
   words_groupb <- table(words_groupb)
@@ -207,7 +213,8 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
       if (y_axes_1 != "only_x_dimension") {
         ggplot2::annotate(
           geom = "text", x = 1, y = 3, label = sum(word_data_all$colour_categories == bivariate_color_codes[1],
-                                                   na.rm = T),
+            na.rm = T
+          ),
           color = titles_color, size = legend_number_size
         )
       }
@@ -216,7 +223,8 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
       if (y_axes_1 != "only_x_dimension") {
         ggplot2::annotate(
           geom = "text", x = 2, y = 3, label = sum(word_data_all$colour_categories == bivariate_color_codes[2],
-                                                   na.rm = T),
+            na.rm = T
+          ),
           color = titles_color, size = legend_number_size
         )
       }
@@ -225,31 +233,36 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
       if (y_axes_1 != "only_x_dimension") {
         ggplot2::annotate(
           geom = "text", x = 3, y = 3, label = sum(word_data_all$colour_categories == bivariate_color_codes[3],
-                                                   na.rm = T),
+            na.rm = T
+          ),
           color = titles_color, size = legend_number_size
         )
       }
     } +
     ggplot2::annotate(
       geom = "text", x = 1, y = 2, label = sum(word_data_all$colour_categories == bivariate_color_codes[4],
-                                               na.rm = T),
+        na.rm = T
+      ),
       color = titles_color, size = legend_number_size
     ) +
     ggplot2::annotate(
       geom = "text", x = 2, y = 2, label = sum(word_data_all$colour_categories == bivariate_color_codes[5],
-                                               na.rm = T),
+        na.rm = T
+      ),
       color = titles_color, size = legend_number_size
     ) +
     ggplot2::annotate(
       geom = "text", x = 3, y = 2, label = sum(word_data_all$colour_categories == bivariate_color_codes[6],
-                                               na.rm = T),
+        na.rm = T
+      ),
       color = titles_color, size = legend_number_size
     ) +
     {
       if (y_axes_1 != "only_x_dimension") {
         ggplot2::annotate(
           geom = "text", x = 1, y = 1, label = sum(word_data_all$colour_categories == bivariate_color_codes[7],
-                                                   na.rm = T),
+            na.rm = T
+          ),
           color = titles_color, size = legend_number_size
         )
       }
@@ -258,7 +271,8 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
       if (y_axes_1 != "only_x_dimension") {
         ggplot2::annotate(
           geom = "text", x = 2, y = 1, label = sum(word_data_all$colour_categories == bivariate_color_codes[8],
-                                                   na.rm = T),
+            na.rm = T
+          ),
           color = titles_color, size = legend_number_size
         )
       }
@@ -267,7 +281,8 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
       if (y_axes_1 != "only_x_dimension") {
         ggplot2::annotate(
           geom = "text", x = 3, y = 1, label = sum(word_data_all$colour_categories == bivariate_color_codes[9],
-                                                   na.rm = T),
+            na.rm = T
+          ),
           color = titles_color, size = legend_number_size
         )
       }
@@ -284,7 +299,7 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
 }
 
 #' Computes the dot product projection for added data.
-#' @return Word_data_all_yadjusted with added infomration for the added words.
+#' @return Word_data_all_yadjusted with added information for the added words.
 #' @noRd
 textOwnWordsProjection <- function(word_data = word_data,
                                    word_data_all = word_data_all,
@@ -355,27 +370,31 @@ textOwnWordsProjection <- function(word_data = word_data,
       #### Create token and aggregated word embeddings ####
       # Aggregate the words
       Aggregated_embedding_added_words <- tibble::as_tibble_row(textEmbeddingAggregation(singlewords_we_x_scaled,
-                                                                                         aggregation = explore_words_aggregation))
+        aggregation = explore_words_aggregation
+      ))
 
       Mean1 <- dplyr::bind_cols(words, n_words, Aggregated_embedding_added_words)
       manual_words_mean1 <- bind_rows(singlewords_we_x_scaled_w_n, Mean1)
     } else {
       # Aggregate the words
-      Aggregated_embedding_added_words <- tibble::as_tibble_row(textEmbeddingAggregation(dplyr::select(explore_words_embeddings$singlewords_we,
-                                                                                                       dplyr::starts_with("Dim")),
-                                                                                         aggregation = explore_words_aggregation))
+      Aggregated_embedding_added_words <- tibble::as_tibble_row(textEmbeddingAggregation(dplyr::select(
+        explore_words_embeddings$singlewords_we,
+        dplyr::starts_with("Dim")
+      ),
+      aggregation = explore_words_aggregation
+      ))
       Mean1 <- dplyr::bind_cols(words, n_words, Aggregated_embedding_added_words)
       manual_words_mean1 <- bind_rows(explore_words_embeddings$singlewords_we, Mean1)
     }
 
     #### Project embedding on the x axes ######
     projected_embedding.x <- as.vector(word_data$background[[1]]$Aggregated_word_embedding_group2.x -
-                                         word_data$background[[1]]$Aggregated_word_embedding_group1.x)
+      word_data$background[[1]]$Aggregated_word_embedding_group1.x)
 
     # Position words in relation to Aggregated word embedding
     # Position the embedding; i.e., taking the word embedding subtracted with aggregated word embedding
     embedding_to_anchour_with.x <- tibble::as_tibble((word_data$background[[1]]$Aggregated_word_embedding_group2.x +
-                                                        word_data$background[[1]]$Aggregated_word_embedding_group1.x) / 2)
+      word_data$background[[1]]$Aggregated_word_embedding_group1.x) / 2)
     manual_words_mean1_1.x <- dplyr::select(manual_words_mean1, dplyr::starts_with("Dim"))
 
     embedding_to_anchour_with.x_df <- embedding_to_anchour_with.x %>%
@@ -401,11 +420,11 @@ textOwnWordsProjection <- function(word_data = word_data,
 
     if (y_axes == TRUE) {
       projected_embedding.y <- as.vector(word_data$background[[2]]$Aggregated_word_embedding_group2.y -
-                                           word_data$background[[2]]$Aggregated_word_embedding_group1.y)
+        word_data$background[[2]]$Aggregated_word_embedding_group1.y)
       # Position words in relation to Aggregated word embedding
       # Position the embedding; i.e., taking the word embedding subtracted with aggregated word embedding
       embedding_to_anchour_with.y <- tibble::as_tibble((word_data$background[[2]]$Aggregated_word_embedding_group2.y +
-                                                          word_data$background[[2]]$Aggregated_word_embedding_group1.y) / 2)
+        word_data$background[[2]]$Aggregated_word_embedding_group1.y) / 2)
       manual_words_mean1_1.y <- dplyr::select(manual_words_mean1, dplyr::starts_with("Dim"))
 
       embedding_to_anchour_with.y_df <- embedding_to_anchour_with.y %>%
@@ -446,8 +465,10 @@ textOwnWordsProjection <- function(word_data = word_data,
     explore_words_results$n <- rep(mean(word_data_all$n), nrow(explore_words_results))
     explore_words_results$n.percent <- rep(0.5, nrow(explore_words_results))
     explore_words_results$n_g2.x <- rep(5, nrow(explore_words_results))
-    explore_words_results$N_participant_responses <- rep(max(word_data_all$N_participant_responses),
-                                                         nrow(explore_words_results))
+    explore_words_results$N_participant_responses <- rep(
+      max(word_data_all$N_participant_responses),
+      nrow(explore_words_results)
+    )
 
     added_words_information[[i_add_w]] <- explore_words_results
   }
@@ -513,9 +534,12 @@ textOwnWordPrediction <- function(word_data = word_data,
     colnames(n_words) <- "n"
 
     # Aggregate the words
-    Aggregated_embedding_added_words <- tibble::as_tibble_row(textEmbeddingAggregation(dplyr::select(explore_words_embeddings$singlewords_we,
-                                                                                                     dplyr::starts_with("Dim")),
-                                                                                       aggregation = explore_words_aggregation))
+    Aggregated_embedding_added_words <- tibble::as_tibble_row(textEmbeddingAggregation(dplyr::select(
+      explore_words_embeddings$singlewords_we,
+      dplyr::starts_with("Dim")
+    ),
+    aggregation = explore_words_aggregation
+    ))
     Mean1 <- dplyr::bind_cols(words, n_words, Aggregated_embedding_added_words)
     manual_words_mean1 <- bind_rows(explore_words_embeddings$singlewords_we, Mean1)
 
@@ -588,7 +612,6 @@ adjust_for_plot_type <- function(word_data, y_axes) {
   return(word_data)
 }
 
-
 #' Plot words from textProjection() or textWordPrediction().
 #' @param word_data Dataframe from textProjection
 #' @param k_n_words_to_test Select the k most frequent words to significance
@@ -857,16 +880,20 @@ textPlot <- function(word_data,
   }
   # word_data_padjusted$p_values_x
   word_data_padjusted$adjusted_p_values.x <- stats::p.adjust(purrr::as_vector(word_data_padjusted[, "p_values_x"]),
-                                                             method = p_adjust_method)
+    method = p_adjust_method
+  )
   word_data1 <- dplyr::left_join(word_data$word_data, word_data_padjusted[, c("words", "adjusted_p_values.x")],
-                                 by = "words")
+    by = "words"
+  )
   # word_data$adjusted_p_values.x
 
   if (is.null(y_axes_1) == FALSE) {
     # Computing adjusted p-values
     word_data1_padjusted_y <- word_data1[word_data1$n >= min_freq_words_test, ]
-    word_data1_padjusted_y$adjusted_p_values.y <- stats::p.adjust(purrr::as_vector(word_data1_padjusted_y[, "p_values_y"]),
-                                                                  method = p_adjust_method)
+    word_data1_padjusted_y$adjusted_p_values.y <- stats::p.adjust(
+      purrr::as_vector(word_data1_padjusted_y[, "p_values_y"]),
+      method = p_adjust_method
+    )
     word_data1 <- left_join(word_data1, word_data1_padjusted_y[, c("words", "adjusted_p_values.y")], by = "words")
   }
 
@@ -1085,12 +1112,12 @@ textPlot <- function(word_data,
     # Select words with MORE words in G1 and POSITIVE dot product (i.e., remove words that are
     # more represented in the opposite group of its dot product projection)
     word_data_all$colour_categories[(abs(word_data_all$n_g1.x) > abs(word_data_all$n_g2.x) &
-                                       word_data_all$x_plotted > 0)] <- n_contrast_group_color
+      word_data_all$x_plotted > 0)] <- n_contrast_group_color
 
     # Select words with MORE words in G2 and POSITIVE dot product (i.e., remove words that are more
     # represented in the opposite group of its dot product projection)
     word_data_all$colour_categories[(abs(word_data_all$n_g1.x) < abs(word_data_all$n_g2.x) &
-                                       word_data_all$x_plotted < 0)] <- n_contrast_group_color
+      word_data_all$x_plotted < 0)] <- n_contrast_group_color
   }
 
   #### Remove more frequent words on the opposite side of the dot product projection ####
