@@ -29,6 +29,27 @@ test_that("textSimilarity produces similarity scores", {
   expect_that(similarity_norm_scores, is_a("numeric"))
 })
 
+test_that("textSimilarityMatrix produces euclidean similarity scores", {
+  skip_on_cran()
+
+  similarity_scores <- textSimilarityMatrix(
+    word_embeddings_4$harmonytexts[1:3, ],
+    method = "euclidean"
+  )
+  expect_that(similarity_scores[[2]], is_a("numeric"))
+})
+
+
+test_that("textDistance produces distance scores", {
+  skip_on_cran()
+
+  distance_scores <- textDistance(
+    word_embeddings_4$harmonytexts,
+    word_embeddings_4$satisfactiontexts
+  )
+  expect_that(distance_scores, is_a("numeric"))
+})
+
 test_that("textSimilarityTest paired results in list with numeric output", {
   skip_on_cran()
 
@@ -71,3 +92,15 @@ test_that("textSimilarityTest unpaired results in list with numeric output", {
   expect_that(test_diff_results, is_a("list"))
   expect_is(test_diff_results$p.value[[1]], "numeric")
 })
+
+test_that("textSimilarityTest unpaired euclidean results in list with numeric output", {
+  skip_on_cran()
+
+  test_diff_results <- textSimilarityTest(word_embeddings_4$harmonytexts, word_embeddings_4$satisfactiontexts,
+    method = "unpaired", Npermutations = 100, N_cluster_nodes = 1,
+    similarity_method = "euclidean"
+  )
+
+  expect_that(test_diff_results, is_a("list"))
+  expect_is(test_diff_results$p.value[[1]], "numeric")
+})
